@@ -57,16 +57,16 @@ corpus_reshape.corpus <- function(x, to = c("sentences", "paragraphs", "document
         docnum <- as.integer(droplevels(attrs$docvars[["docid_"]]))
         temp <- list("text" = split(unclass(x), docnum))
         if (field_object(attrs, "unit") %in% c("sentences", "segments", "segments")) {
-            temp[["text"]] <- unlist(lapply(temp[["text"]], paste0, collapse = "  "))
+            temp[["text"]] <- unlist_character(lapply(temp[["text"]], paste0, collapse = "  "))
         } else {
-            temp[["text"]] <- unlist(lapply(temp[["text"]], paste0, collapse = "\n\n"))
+            temp[["text"]] <- unlist_character(lapply(temp[["text"]], paste0, collapse = "\n\n"))
         }
-        attrs[["docvars"]] <- reshape_docvars(attrs[["docvars"]], !duplicated(docnum))
+        attrs[["docvars"]] <- reshape_docvars(attrs[["docvars"]], !duplicated(docnum), unique = TRUE)
         unit <- "documents"
     } else {
         temp <- segment_texts(x,  pattern = NULL, extract_pattern = FALSE,
                               omit_empty = FALSE, what = to, ...)
-        attrs[["docvars"]] <- reshape_docvars(attrs[["docvars"]], temp[["docnum"]])
+        attrs[["docvars"]] <- reshape_docvars(attrs[["docvars"]], temp[["docnum"]], unique = FALSE)
         unit <- to
     }
     build_corpus(
